<?php
namespace Dominie\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Dominie.
* @since 1.0.0
**/
class Dmne_Banner extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'dmne-banner';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Dmne Banner', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return ' eicon-post-title';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'dominie_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'dominie' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
			]
		);

		$this->add_control(
			'banner-style',
			[
				'label' => __( 'Banner Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Banner 1', 'dominie' ),
					'2' => __( 'Banner 2', 'dominie' ),
					'3' => __( 'Banner 3', 'dominie' ),
					'4' => __( 'Banner 4', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'banner-title',
			[
				'label' => esc_html__( 'Banner Title', 'dominie' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Add Your Banner title', 'dominie' ),
			]
		);
		$this->add_control(
			'banner-content',
			[
				'label' => esc_html__( 'Banner Content', 'dominie' ),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __( 'Add Your Banner Content', 'dominie' ),
			]
		);
		$this->add_control(
			'search-hide',
			[
				'label' => __( 'Search Hide', 'dominie' ),
				'type' => Controls_Manager::SWITCHER,
			]
		);
		$this->add_control(
	   		'image',
	      	[
	          'label' => esc_html__( 'Banner Background Image', 'dominie' ),
	          'type'  => Controls_Manager::MEDIA,
				'dynamic' => [
				'active' => true,
			   ],
	    	]
	    );



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'dominie' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label' => __( 'Icon Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .main-search-inner i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'dominie' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'dominie' ),
					'lowercase' => esc_html__( 'lowercase', 'dominie' ),
					'capitalize' => esc_html__( 'Capitalize', 'dominie' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$images = $settings['image'];
		$image_id = $settings['image']['id'];
		$image_url = wp_get_attachment_image_src( $image_id, 'full', false ); ?>

		<?php if ($settings['banner-style'] == 2) { ?>
			<div class="banner-area style-two">
		        <div class="container">
		            <div class="banner-area-inner">
		                <div class="row">
		                    <div class="col-xl-5 col-lg-7 col-md-10">
		                        <div class="banner-inner">
		                            <?php if (!empty($settings['banner-title'])) { ?>
						        		<h2><?php echo esc_html( $settings['banner-title']  ); ?></h2>
						        	<?php } ?>
						        	<?php if (!empty($settings['banner-content'])) { ?>
						        		<p><?php echo esc_html( $settings['banner-content']  ); ?></p>
						        	<?php } ?>
						        	<?php if (empty($settings['search-hide'])) { ?>
						        		<form method="get" class="main-search-inner" action="<?php print esc_url( home_url( '/' ) ); ?>">
			                            	<i class="fa fa-search"></i>
							                <input type="search" placeholder="<?php print esc_html__( 'Search', 'dominie' ); ?>" value="<?php print get_search_query(); ?>" name="s" />
								        </form>
						        	<?php } ?>
		                        </div>
		                    </div>
		                </div>
		            </div>
		        </div>
		    </div>	
		<?php } elseif($settings['banner-style'] == 3){ ?>
			<div class="banner-area style-three">
	            <div class="banner-area-inner">
	                <div class="row">
	                    <div class="col-md-6 col-sm-8 order-md-last">
	                        <div class="thumb mb-3 mb-md-0">
	                            <img src="<?php echo $images['url'] ?>" alt="img">
	                        </div>
	                    </div>   
	                    <div class="col-md-6 order-md-first align-self-center">
	                        <div class="banner-inner">
	                            <?php if (!empty($settings['banner-title'])) { ?>
					        		<h2><?php echo esc_html( $settings['banner-title']  ); ?></h2>
					        	<?php } ?>
	                            <?php if (!empty($settings['banner-content'])) { ?>
					        		<p><?php echo esc_html( $settings['banner-content']  ); ?></p>
					        	<?php } ?>
	                            <?php if (empty($settings['search-hide'])) { ?>
					        		<form method="get" class="main-search-inner main-search-bg" action="<?php print esc_url( home_url( '/' ) ); ?>">
		                            	<i class="fa fa-search"></i>
						                <input type="search" placeholder="<?php print esc_html__( 'Search', 'dominie' ); ?>" value="<?php print get_search_query(); ?>" name="s" />
							        </form>
					        	<?php } ?>
	                        </div>
	                    </div>
	                </div>
	            </div>
		    </div>
		<?php } elseif($settings['banner-style'] == 4){ ?>
			<div class="banner-area">
	            <div class="banner-area-inner" style="background: url( <?php echo esc_url( $image_url[0] ); ?> );">
	                <div class="row">
	                    <div class="col-xl-8 col-lg-10">
	                        <div class="banner-inner">
	                        	<?php if (!empty($settings['banner-title'])) { ?>
					        		<h2><?php echo esc_html( $settings['banner-title']  ); ?></h2>
					        	<?php } ?>
					        	<?php if (!empty($settings['banner-content'])) { ?>
					        		<p><?php echo esc_html( $settings['banner-content']  ); ?></p>
					        	<?php } ?>
					        	<?php if (empty($settings['search-hide'])) { ?>
					        		<form method="get" class="main-search-inner" action="<?php print esc_url( home_url( '/' ) ); ?>">
		                            	<i class="fa fa-search"></i>
						                <input type="search" placeholder="<?php print esc_html__( 'Search', 'dominie' ); ?>" value="<?php print get_search_query(); ?>" name="s" />
							        </form>
					        	<?php } ?>
	                        </div>
	                    </div>
	                </div>
	            </div>
		    </div>
		<?php }else { ?>
			<div class="banner-area">
	            <div class="banner-area-inner" style="background: url( <?php echo esc_url( $image_url[0] ); ?> );">
	                <div class="row">
	                    <div class="col-xl-5 col-lg-7 col-md-10">
	                        <div class="banner-inner">
	                        	<?php if (!empty($settings['banner-title'])) { ?>
					        		<h2><?php echo esc_html( $settings['banner-title']  ); ?></h2>
					        	<?php } ?>
					        	<?php if (!empty($settings['banner-content'])) { ?>
					        		<p><?php echo esc_html( $settings['banner-content']  ); ?></p>
					        	<?php } ?>
					        	<?php if (empty($settings['search-hide'])) { ?>
					        		<form method="get" class="main-search-inner" action="<?php print esc_url( home_url( '/' ) ); ?>">
		                            	<i class="fa fa-search"></i>
						                <input type="search" placeholder="<?php print esc_html__( 'Search', 'dominie' ); ?>" value="<?php print get_search_query(); ?>" name="s" />
							        </form>
					        	<?php } ?>
	                        </div>
	                    </div>
	                </div>
	            </div>
		    </div>
		<?php }
	}
}
