<?php
namespace Dominie\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
* Elementor Widget
* Elementor widget for Dominie.
* @since 1.0.0
**/
class Dmne_Blog extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	**/
	public function get_name() {
		return 'dmne-blog';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Dmne Blog', 'dominie' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-menu-card';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'dominie_widgets' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'dominie' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'dominie' ),
			]
		);

		$this->add_control(
			'blog-style',
			[
				'label' => __( 'Blog Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __( 'Blog 1', 'dominie' ),
					'2' => __( 'Blog 2', 'dominie' ),
					'3' => __( 'Blog 3', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'blog-column',
			[
				'label' => __( 'Blog Column Style', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-4' => __( 'col-lg-4', 'dominie' ),
					'col-lg-6' => __( 'col-lg-6', 'dominie' ),
					'col-lg-3' => __( 'col-lg-3', 'dominie' ),
					'col-lg-12' => __( 'col-lg-12', 'dominie' ),
				],
			]
		);

		$this->add_control(
			'post-order',
			[
				'label' => __( 'Post Order', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC' => __( 'ASC', 'dominie' ),
					'DSC' => __( 'DSC', 'dominie' ),
				],
			]
		);
		$this->add_control(
			'post-limit',
			[
				'label'       => esc_html__( 'Post Limit', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Display', 'dominie' ),
				'default'     => esc_html__('-1','dominie')
			]
		);

		$this->add_control(
			'post-offset',
			[
				'label'       => esc_html__( 'Post Offset', 'dominie' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'How Many Post You Offset', 'dominie' ),
				'default'     => esc_html__('0','dominie')
			]
		);



		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'dominie' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		//color style field
		$this->add_control(
			'date-color',
			[
				'label' => __( 'Date Color', 'forgood' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .single-blog-inner.style-two .details p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'text_transform',
			[
				'label' => esc_html__( 'Text Transform', 'dominie' ),
				'type' => Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'None', 'dominie' ),
					'uppercase' => esc_html__( 'UPPERCASE', 'dominie' ),
					'lowercase' => esc_html__( 'lowercase', 'dominie' ),
					'capitalize' => esc_html__( 'Capitalize', 'dominie' ),
				],
				'selectors' => [
					'{{WRAPPER}} .title' => 'text-transform: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	*/
	protected function render() {
		$settings = $this->get_settings_for_display(); 
		$course_column  = (isset($settings['blog-column']) ? $settings['blog-column'] : 'col-lg-4');  ?>


		<div class="blog-area">

			<?php $blog_query = new \WP_Query(array('post_type'=> 'post', 'order'=> $settings['post-order'], 'posts_per_page' => $settings['post-limit'], 'offset' => $settings['post-offset'] ));
			if($settings['blog-style'] == 2){ ?>
				<div class="row justify-content-center">
					<?php if($blog_query->have_posts()) : 
						while($blog_query->have_posts()) : $blog_query->the_post(); ?>
			                <div class="<?php echo $course_column ?> col-md-6">
			                    <div class="single-blog-inner">
			                        <div class="thumb">
			                            <?php echo get_the_post_thumbnail( null, 'dominie-blog-thumbnail-2', array('class'=> 'img-responsive') ) ?>
			                        </div>
			                        <div class="details">
			                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
			                            <p><?php the_author() ?></p>
			                        </div>
			                    </div>
			                </div>
						<?php endwhile;
						wp_reset_postdata();
					endif;	?>
				</div>
			<?php }elseif($settings['blog-style'] == 3){ 
				if($blog_query->have_posts()) : 
					while($blog_query->have_posts()) : $blog_query->the_post(); ?>
	                    <div class="single-video-inner single-leading-blog-inner mb-4">
	                        <div class="row">
	                            <div class="col-md-6">
	                                <div class="thumb">
	                                    <?php echo get_the_post_thumbnail( null, 'dominie-blog-thumbnail-3', array('class'=> 'img-responsive') ) ?>
	                                </div>
	                            </div>
	                            <div class="col-md-6 align-self-center">
	                                <div class="details">
	                                    <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
	                                    <p><?php print wp_trim_words( get_the_content(), 19, null ); ?></p>
	                                    <div class="media mt-xl-5 mt-4">
	                                        <div class="media-left">
	                                            <?php $user = wp_get_current_user();
												if ( $user ) : ?>
												    <img src="<?php echo esc_url( get_avatar_url( $user->ID ) ); ?>" alt="img"/>
												<?php endif; ?>
	                                        </div>
	                                        <div class="media-body align-self-center">
	                                            <h6><?php the_author() ?></h6>
	                                            <p><?php echo $user->roles[0] ?></p>
	                                        </div>
	                                    </div>
	                                </div>
	                            </div>
	                        </div>
	                    </div>
					<?php endwhile;
					wp_reset_postdata();
				endif;
			} else { ?>
				<div class="row justify-content-center">
					<?php if($blog_query->have_posts()) : 
						while($blog_query->have_posts()) : $blog_query->the_post(); ?>
							<div class="<?php echo $course_column ?> col-md-6">
			                    <div class="single-blog-inner style-two">
			                        <div class="thumb">
			                            <?php echo get_the_post_thumbnail( null, 'dominie-blog-thumbnail', array('class'=> 'img-responsive') ) ?>
			                        </div>
			                        <div class="details">
			                            <h5><a href="<?php echo get_the_permalink(); ?>"><?php echo get_the_title(); ?></a></h5>
			                            <p class="date"><?php echo get_the_date('M d Y') ?></p>
			                        </div>
			                    </div>
			                </div>
						<?php endwhile;
						wp_reset_postdata();
					endif; ?>
				</div>
			<?php } ?>
		</div>
	<?php }
}